instrumenttools.transpose_from_sounding_pitch_to_written_pitch
==============================================================

.. autofunction:: abjad.tools.instrumenttools.transpose_from_sounding_pitch_to_written_pitch.transpose_from_sounding_pitch_to_written_pitch
